@@ -12,7 +12,7 @@ ORDER_STATUS_REJECTED = 'REJECTED'
 ORDER_STATUS_EXPIRED = 'EXPIRED'
 
 KLINE_INTERVAL_1MINUTE = '1m'
-KLINE_INTERVAL_2MINUTE = '3m'
+KLINE_INTERVAL_3MINUTE = '3m'
 KLINE_INTERVAL_5MINUTE = '5m'
 KLINE_INTERVAL_15MINUTE = '15m'
 KLINE_INTERVAL_30MINUTE = '30m'
@@ -35,3 +35,11 @@ ORDER_TYPE_MARKET = 'MARKET'
 
 TIME_IN_FORCE_GTC = 'GTC'  # Good till cancelled
 TIME_IN_FORCE_IOC = 'IOC'  # Immediate or cancel
+
+WEBSOCKET_UPDATE_0SECOND = '0ms'
+WEBSOCKET_UPDATE_1SECOND = '1000ms'
+
+WEBSOCKET_DEPTH_1 = '1'
+WEBSOCKET_DEPTH_5 = '5'
+WEBSOCKET_DEPTH_10 = '10'
+WEBSOCKET_DEPTH_20 = '20'
